Struct kas_wgpu::options::Options[][src]

pub struct Options {
    pub config_path: PathBuf,
    pub config_mode: ConfigMode,
    pub power_preference: PowerPreference,
    pub backends: BackendBit,
}

Shell options

Fields

config_path: PathBuf

Config file path. Default: empty. See KAS_CONFIG doc.

config_mode: ConfigMode

Config mode. Default: Read.

power_preference: PowerPreference

Adapter power preference. Default value: low power.

backends: BackendBit

Adapter backend. Default value: PRIMARY (Vulkan/Metal/DX12).

Implementations

impl Options[src]

pub fn from_env() -> Self[src]

Construct a new instance, reading from environment variables

The following environment variables are read, in case-insensitive mode.

Config

The KAS_CONFIG variable, if given, provides a path to the KAS config file, where configuration can be read and/or written.

WARNING: file formats are unstable!

If KAS_CONFIG is not set, platform-default configuration is used without reading or writing. This may change to use a platform-specific default path in future versions.

The KAS_CONFIG_MODE variable determines the read/write mode:

  • Read (default): read-only
  • WriteDefault: generate platform-default configuration, and write it to the config path, overwriting any existing config

Note: in the future, the default will likely change to a read-write mode, allowing changes to be written out.

Power preference

The KAS_POWER_PREFERENCE variable supports:

  • Default
  • LowPower
  • HighPerformance

Backend

The KAS_BACKENDS variable supports:

  • Vulkan
  • GL
  • Metal
  • DX11
  • DX12
  • PRIMARY: any of Vulkan, Metal or DX12
  • SECONDARY: any of GL or DX11

pub fn config(&self) -> Result<Config, Error>[src]

Load KAS config